*species*
=========

**spe**\ctral **c**\ haracterization and **i**\ nference for **e**\ xoplanet **s**\ cience

.. image:: https://img.shields.io/pypi/v/species
   :target: https://pypi.python.org/pypi/species

.. image:: https://img.shields.io/pypi/pyversions/species
   :target: https://pypi.python.org/pypi/species

.. image:: https://img.shields.io/travis/tomasstolker/species
   :target: https://travis-ci.org/tomasstolker/species

.. image:: https://img.shields.io/readthedocs/species
   :target: http://species.readthedocs.io

.. image:: https://img.shields.io/coveralls/github/tomasstolker/species
   :target: https://coveralls.io/github/tomasstolker/species

.. image:: https://img.shields.io/codefactor/grade/github/tomasstolker/species
   :target: https://www.codefactor.io/repository/github/tomasstolker/species

.. image:: https://img.shields.io/github/license/tomasstolker/species
   :target: https://github.com/tomasstolker/species/blob/master/LICENSE

.. image:: https://mybinder.org/badge_logo.svg
   :target: https://mybinder.org/v2/gh/tomasstolker/species/HEAD

*species* is a toolkit for atmospheric characterization of directly imaged exoplanets. It provides a coherent framework for spectral and photometric analysis which builds on publicly-available data and models from various resources. There are tools available for both grid retrievals and free retrievals with Bayesian inference, color-magnitude and color-color diagrams, empirical spectral analysis, spectral and photometric calibration, analysis of emission lines, and synthetic photometry. The package has been released on `PyPI <https://pypi.org/project/species/>`_ and is actively developed and maintained on Github.

Documentation
-------------

Documentation can be found at `http://species.readthedocs.io <http://species.readthedocs.io>`_.

Tutorials
---------

There are several `Jupyter notebooks <https://species.readthedocs.io/en/latest/tutorials.html>`_ with tutorials that showcase the workflow and available tools. They can also be executed on `Binder <https://mybinder.org/v2/gh/tomasstolker/species/HEAD>`_ by navigating to the *docs/tutorials* folder.

Attribution
-----------

Please cite `Stolker et al. (2020) <https://ui.adsabs.harvard.edu/abs/2020A%26A...635A.182S/abstract>`_ whenever results from *species* are used in a publication. Please also make sure to give credit to the relevant papers regarding the use of the publicly available data that *species* benefits from. The *species* logo is `available <https://home.strw.leidenuniv.nl/~stolker/species/species_logo.zip>`_ for use in presentations.

Contributing
------------

Contributions are welcome so please consider forking the repository and creating a pull request. Bug reports can be provided by creating an `issue <https://github.com/tomasstolker/species/issues>`_ on the Github page.

License
-------

Copyright 2018-2021 Tomas Stolker

*species* is distributed under the MIT License. See the LICENSE file for the terms and conditions.
